@@ -1,5 +1,9 @@
 #!/bin/bash
 
+set -e
+
+cd $(dirname "$0")/..
+
 IMAGE=${DOCKER_IMAGE_NAME:-"element-desktop-dockerbuild"}
 
 docker inspect "$IMAGE" 2> /dev/null > /dev/null
@@ -8,6 +12,8 @@ if [ $? != 0 ]; then
     exit 1
 fi
 
+mkdir -p docker/node_modules docker/.hak docker/.gnupg
+
 # Taken from https://www.electron.build/multi-platform-build#docker
 # Pass through any vars prefixed with INDOCKER_, removing the prefix
 docker run --rm -ti \
